pub fn parse<T: DeserializeOwned>(text: &str) -> Result<Vec<T>, ParseError>Expand description
Deserialize one row per non-blank line. The first line that does not deserialize stops the parse and is reported by its one-based number.
pub fn parse<T: DeserializeOwned>(text: &str) -> Result<Vec<T>, ParseError>Deserialize one row per non-blank line. The first line that does not deserialize stops the parse and is reported by its one-based number.